#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 witherable
version:              0.5
visibility:           public
id:                   witherable-0.5-ULSOQpIk2yIdvPdv1uJwA
key:                  witherable-0.5-ULSOQpIk2yIdvPdv1uJwA
license:              BSD-3-Clause
copyright:            Copyright (c) 2014 Fumiaki Kinoshita
maintainer:           Fumiaki Kinoshita <fumiexcel@gmail.com>
author:               Fumiaki Kinoshita
homepage:             https://github.com/fumieval/witherable
synopsis:             filterable traversable
description:
    A stronger variant of `traverse` which can remove elements and generalised mapMaybe, catMaybes, filter

category:             Data
abi:                  ac60b6880c86a2931e67489a1f163f55
exposed:              True
exposed-modules:      Witherable
import-dirs:          /usr/lib/ghc-9.6.6/site-local/witherable-0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/witherable-0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/witherable-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-witherable
hs-libraries:         HSwitherable-0.5-ULSOQpIk2yIdvPdv1uJwA
depends:
    base-4.18.2.1 base-orphans-0.9.4-ZTNVGfO44s5Gaz9IblFIi
    containers-0.6.7 hashable-1.4.7.0-8JCT2FqI0OIc7eryHiY9E
    indexed-traversable-0.1.5-joXpPaCxYw3UYRlFaP36
    indexed-traversable-instances-0.1.2.1-AomlPdkeUExE0hyPfZlDZQ
    transformers-0.6.1.0
    unordered-containers-0.2.21-KyMpciGvYH9aykbB6p5Z
    vector-0.13.2.0-pkGAkHyCfVA94J1hIBHJi

haddock-interfaces:   /usr/share/doc/haskell-witherable/html/witherable.haddock
haddock-html:         /usr/share/doc/haskell-witherable/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

